@@ -1,7 +1,10 @@
 import os
 import shutil
 
-from ConfigParser import SafeConfigParser
+try:
+    from configparser import SafeConfigParser  # py3
+except:
+    from ConfigParser import SafeConfigParser
 
 PATH_PACKAGE = os.path.dirname(__file__)
 FILE_CONFIG_SAMPLE = os.path.join(PATH_PACKAGE, 'sydep.cfg.sample')
@@ -31,7 +34,7 @@ def copy_config():
     """
     try:
         open('./sydep.cfg', 'r')
-        print 'Remove sydep.cfg first. It cannot be overwritten.'
+        print('Remove sydep.cfg first. It cannot be overwritten.')
     except:
         shutil.copyfile(FILE_CONFIG_SAMPLE, './sydep.cfg')
         open('./.sydepignore', 'a').close()
@@ -89,6 +92,6 @@ def run_cmd(cmd, config, args):
     )
 
     if not args['--quiet']:
-        print cmd
+        print(cmd)
 
     os.system(cmd)
